Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(245)

Unified Diff: editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/internal/model/DartProjectImpl.java

Issue 10563005: fix mapping of html files to libraries http://code.google.com/p/dart/issues/detail?id=3586 (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/internal/model/DartProjectImpl.java
===================================================================
--- editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/internal/model/DartProjectImpl.java (revision 8721)
+++ editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/internal/model/DartProjectImpl.java (working copy)
@@ -37,6 +37,7 @@
import com.google.dart.tools.core.utilities.compiler.DartCompilerUtilities;
import com.google.dart.tools.core.utilities.io.FileUtilities;
import com.google.dart.tools.core.utilities.resource.IFileUtilities;
+import com.google.dart.tools.core.utilities.resource.IResourceUtilities;
import com.google.dart.tools.core.workingcopy.WorkingCopyOwner;
import org.eclipse.core.resources.IFile;
@@ -417,7 +418,8 @@
* Return the mapping for the html files contained in this project. If the mapping has not been
* created, it will do so and return the result.
*
* @return the table with the html file to library mapping
* @throws CoreException
*/
@Override
@@ -442,7 +444,10 @@
try {
List<String> libraryNames = LibraryReferenceFinder.findInHTML(IFileUtilities.getContents((IFile) resource));
if (!libraryNames.isEmpty()) {
- mapping.put(resource.getLocation().toPortableString(), libraryNames);
+ List<String> libraryPaths = IResourceUtilities.getResolvedFilePaths(
+ resource,
+ libraryNames);
+ mapping.put(resource.getLocation().toPortableString(), libraryPaths);
}
} catch (IOException exception) {
DartCore.logInformation(
@@ -417,7 +418,8 @@
* created, it will do so and return the result.
*
- * @return the table with the html file to library mapping
+ * @return the table with the html file to library mapping html file location string, list of
+ * library resource location string
* @throws CoreException
*/

Powered by Google App Engine
This is Rietveld 408576698